@@ -105,7 +105,9 @@ class Microservice(core.Construct):
         
         will_use_ldap (str): Wether or not the EC2 instance should be able to integrate with LDAP. This configuration set-up the LDAP client security group to the EC2
 
-        existing_efs_security_group (str): In case you want to enble access to an existing EFS, provide its already-existing security group
+        existing_efs_security_group (str): In case you want to enble access to an existing EFS, provide its security group resource. If provided, `existing_efs_security_group_id` will be ignored
+        
+        existing_efs_security_group_id (str): In case you want to enble access to an existing EFS, provide its already-existing security group ID. If `existing_efs_security_group`, this will be ignored. Important: `existing_efs_security_group_id` works only if the Security Group is already existing and deployed on AWS. Not compabible with security groups created during the first deployment.
     """
 
     @property
@@ -530,6 +532,7 @@ class Microservice(core.Construct):
         will_use_ldap=None,
         additional_variables: dict = None,
         existing_efs_security_group = None,
+        existing_efs_security_group_id = None,
         **kwargs
     ):
         super().__init__(scope, id, **kwargs)
@@ -1203,8 +1206,12 @@ class Microservice(core.Construct):
         self._asg.add_security_group(self.ec2_security_group)
 
         # Enable access to already existing EFS
-        if existing_efs_security_group:
-            existing_efs_security_group_resource = _ec2.SecurityGroup.from_security_group_id(
+        if existing_efs_security_group or existing_efs_security_group_id:
+
+            # In case `existing_efs_security_group` is provided use it, otherwise retrive the security group from AWS.
+            # Important: `existing_efs_security_group_id` works only if the Security Group is already deployed. Not compabible with security groups created during the 
+            # first deployment            
+            existing_efs_security_group_resource = existing_efs_security_group if existing_efs_security_group else _ec2.SecurityGroup.from_security_group_id(
                 self,
                 "existing_efs_security_group",
                 existing_efs_security_group,
